@@ -21,7 +21,7 @@
 
 """Utilities to make logging consistent and easy in :mod:`slimta` packages."""
 
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import threading
 threading._DummyThread._Thread__stop = lambda x: 42
@@ -29,24 +29,26 @@ threading._DummyThread._Thread__stop = lambda x: 42
 import sys
 import traceback
 import re
-import repr
+from six.moves import reprlib
 import logging
 from ast import literal_eval
 
 from .socket import SocketLogger
 from .subprocess import SubprocessLogger
 from .queuestorage import QueueStorageLogger
+from .http import HttpLogger
 
-__all__ = ['getSocketLogger', 'getSubprocessLogger', 'getQueueStorageLogger']
+__all__ = ['getSocketLogger', 'getSubprocessLogger', 'getQueueStorageLogger',
+           'getHttpLogger', 'log_exception']
 
 
 def getSocketLogger(name):
-    """Wraps the result of :func:python:`logging.getLogger()` in a
+    """Wraps the result of :py:func:`logging.getLogger()` in a
     :class:`SocketLogger` object to provide limited and consistent logging
     output for socket operations.
 
-    :param name: ``name`` as passed in to :func:python:`logging.getLogger()`.
-    :rtype: :class:`SocketLogger`
+    :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
+    :rtype: :class:`~slimta.logging.socket.SocketLogger`
 
     """
     logger = logging.getLogger(name)
@@ -54,12 +56,12 @@ def getSocketLogger(name):
 
 
 def getSubprocessLogger(name):
-    """Wraps the result of :func:python:`logging.getLogger()` in a
+    """Wraps the result of :py:func:`logging.getLogger()` in a
     :class:`SubprocessLogger` object to provide limited and consistent
     logging output for subprocess operations.
 
-    :param name: ``name`` as passed in to :func:python:`logging.getLogger()`.
-    :rtype: :class:`SubprocessLogger`
+    :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
+    :rtype: :class:`~slimta.logging.subprocess.SubprocessLogger`
 
     """
     logger = logging.getLogger(name)
@@ -67,24 +69,37 @@ def getSubprocessLogger(name):
 
 
 def getQueueStorageLogger(name):
-    """Wraps the result of :func:python:`logging.getLogger()` in a
-    :class:`QueueStorageLogger` object to provide limited and consistent logging
-    output for |QueueStorage| operations.
+    """Wraps the result of :py:func:`logging.getLogger()` in a
+    :class:`QueueStorageLogger` object to provide limited and consistent
+    logging output for |QueueStorage| operations.
 
-    :param name: ``name`` as passed in to :func:python:`logging.getLogger()`.
-    :rtype: :class:`QueueStorageLogger`
+    :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
+    :rtype: :class:`~slimta.logging.queuestorage.QueueStorageLogger`
 
     """
     logger = logging.getLogger(name)
     return QueueStorageLogger(logger)
 
 
+def getHttpLogger(name):
+    """Wraps the result of :py:func:`logging.getLogger()` in a
+    :class:`HttpLogger` object to provide limited and consistent logging output
+    for WSGI-style requests and responses and other HTTP-related logs.
+
+    :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
+    :rtype: :class:`~slimta.logging.http.HttpLogger`
+
+    """
+    logger = logging.getLogger(name)
+    return HttpLogger(logger)
+
+
 def log_exception(name, **kwargs):
     """Logs an exception, along with relevant information such as message,
     traceback, and anything provided pertinent to the situation. This function
     does nothing unless called while an exception is being handled.
 
-    :param name: ``name`` as passed in to :func:python:`logging.getLogger()`.
+    :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
     :param kwargs: Other keywords may be passed in and will be included in the
                    produced log line.
 
@@ -92,7 +107,7 @@ def log_exception(name, **kwargs):
     type, value, tb = sys.exc_info()
     if not value:
         return
-    exc_repr = repr.Repr()
+    exc_repr = reprlib.Repr()
     exc_repr.maxstring = 1000
     logger = logging.getLogger(name)
     data = kwargs.copy()
@@ -100,11 +115,11 @@ def log_exception(name, **kwargs):
     data['traceback'] = traceback.format_exception(type, value, tb)
     data['args'] = value.args
     data_str = ' '.join(['='.join((key, exc_repr.repr(val)))
-                         for key, val in sorted(data.iteritems())])
+                         for key, val in sorted(data.items())])
     logger.error('exception:{0}:unhandled {1}'.format(type.__name__, data_str))
 
 
-log_repr = repr.Repr()
+log_repr = reprlib.Repr()
 log_repr.maxstring = 100
 
 
@@ -113,13 +128,14 @@ def logline(log, type, typeid, operation, **data):
         log('{0}:{1}:{2}'.format(type, typeid, operation))
     else:
         data_str = ' '.join(['='.join((key, log_repr.repr(val)))
-                             for key, val in sorted(data.iteritems())])
+                             for key, val in sorted(data.items())])
         log('{0}:{1}:{2} {3}'.format(type, typeid, operation, data_str))
 
 
 parseline_pattern = re.compile(r'^([^:]+):([^:]+):(\S+) ?(.*)$')
 data_item_pattern = re.compile('^([^=]+)=')
 
+
 def _parseline_data(remaining, data):
     match = data_item_pattern.match(remaining)
     if not match:
@@ -142,6 +158,7 @@ def _parseline_data(remaining, data):
             else:
                 return _parseline_data(remaining[space_i+1:], data)
 
+
 def parseline(line):
     match = parseline_pattern.match(line)
     if not match:
