@@ -29,21 +29,23 @@ matched symbols in ``X-Spam-Symbols``).
 from __future__ import absolute_import
 
 import re
-import cStringIO
+from io import BytesIO
 
 from gevent import Timeout
 from gevent.socket import create_connection, SHUT_WR
 
 from slimta import logging
+from slimta.envelope import Envelope
 from . import PolicyError, QueuePolicy
 
 __all__ = ['SpamAssassinError', 'SpamAssassin']
 
 log = logging.getSocketLogger(__name__)
 
-first_line_pattern = re.compile(r'^SPAMD/[^ ]+ 0 EX_OK$')
-spammy_pattern = re.compile(r'^Spam: ([^ ]+)', re.MULTILINE)
-divider_pattern = re.compile(r'^(.*?)\r?\n(.*?)\r?\n\r?\n', re.DOTALL)
+first_line_pattern = re.compile(br'^SPAMD/[^ ]+ 0 EX_OK$')
+spammy_pattern = re.compile(br'^Spam: ([^ ]+)', re.MULTILINE)
+divider_pattern = re.compile(br'^(.*?)\r?\n(.*?)\r?\n\r?\n', re.DOTALL)
+symbols_pattern = re.compile(br'[^\s,]+')
 
 
 class SpamAssassinError(PolicyError):
@@ -67,26 +69,27 @@ class SpamAssassin(QueuePolicy):
 
     """
 
-    SPAMC_USER = 'slimta'
-    SPAMC_PROTOCOL_VER = '1.1'
+    SPAMC_USER = b'slimta'
+    SPAMC_PROTOCOL_VER = b'1.1'
 
     def __init__(self, address=None, timeout=None, socket_creator=None):
         self.address = address or ('127.0.0.1', 783)
         self.timeout = timeout
-        if socket_creator:
-            self._socket_creator = socket_creator
+        self.custom_socket_creator = socket_creator
 
     def _socket_creator(self, address):
+        if self.custom_socket_creator:
+            return self.custom_socket_creator(address)
         socket = create_connection(address)
         log.connect(socket, address)
         return socket
 
     def _build_request_str(self, header_data, message_data):
-        reqfp = cStringIO.StringIO()
-        data_len = len(header_data) + len(message_data)
-        reqfp.write('SYMBOLS SPAMC/{0}\r\n'.format(self.SPAMC_PROTOCOL_VER))
-        reqfp.write('Content-Length: {0!s}\r\n'.format(data_len))
-        reqfp.write('User: {0}\r\n\r\n'.format(self.SPAMC_USER))
+        reqfp = BytesIO()
+        data_len = str(len(header_data) + len(message_data)).encode('ascii')
+        reqfp.write(b'SYMBOLS SPAMC/' + self.SPAMC_PROTOCOL_VER + b'\r\n')
+        reqfp.write(b'Content-Length: ' + data_len + b'\r\n')
+        reqfp.write(b'User: ' + self.SPAMC_USER + b'\r\n\r\n')
         reqfp.write(header_data)
         reqfp.write(message_data)
         return reqfp.getvalue()
@@ -99,12 +102,12 @@ class SpamAssassin(QueuePolicy):
         log.shutdown(socket, SHUT_WR)
 
     def _recv_all(self, socket):
-        resfp = cStringIO.StringIO()
+        resfp = BytesIO()
         with Timeout(self.timeout):
             while True:
                 data = socket.recv(4096)
                 log.recv(socket, data)
-                if data == '':
+                if data == b'':
                     break
                 resfp.write(data)
         response = resfp.getvalue()
@@ -117,26 +120,33 @@ class SpamAssassin(QueuePolicy):
         return first_line, headers, after
 
     def _recv_response(self, socket):
-        first_line, headers, symbols = self._recv_all(socket)
+        first_line, headers, body = self._recv_all(socket)
+        symbols = symbols_pattern.findall(body)
         match = first_line_pattern.match(first_line)
         if not match:
             raise SpamAssassinError()
         spammy = False
         match = spammy_pattern.search(headers)
-        if match and match.group(1) == 'True':
+        if match and match.group(1) == b'True':
             spammy = True
         return spammy, symbols
 
-    def scan(self, envelope):
+    def scan(self, message):
         """Convenience method that scans a message and returns the results,
         without adding the spam headers.
 
-        :param envelope: |Envelope| object to scan.
-        :returns: Tuple of a spammy boolean followed by a string of the symbols
+        :param message: Message to scan.
+        :type message: :py:obj:`str` or :class:`~slimta.envelope.Envelope`
+        :returns: Tuple of a spammy boolean followed by a list of the symbols
                   matched in the scan.
 
         """
-        header_data, message_data = envelope.flatten()
+
+        if isinstance(message, Envelope):
+            header_data, message_data = message.flatten()
+        else:
+            header_data = b''
+            message_data = message
         socket = None
         try:
             socket = self._socket_creator(self.address)
@@ -151,7 +161,7 @@ class SpamAssassin(QueuePolicy):
         spammy, symbols = self.scan(envelope)
         if spammy:
             envelope.headers['X-Spam-Status'] = 'YES'
-            envelope.headers['X-Spam-Symbols'] = symbols
+            envelope.headers['X-Spam-Symbols'] = ','.join(symbols)
         else:
             envelope.headers['X-Spam-Status'] = 'NO'
 
