@@ -25,21 +25,20 @@ certain situations (typically when a client sends various commands).
 
 """
 
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import re
 
-from gevent.ssl import SSLError
-from gevent.socket import timeout as socket_timeout
 from gevent import Timeout
 from pysasl import SASLAuth
+from six.moves import range
 
 from . import SmtpError, ConnectionLost
 from .datareader import DataReader
 from .io import IO
 from .extensions import Extensions
 from .auth import ServerAuthError, AuthSession
-from .reply import *
+from .reply import *  # NOQA
 
 __all__ = ['Server']
 
@@ -53,7 +52,7 @@ def find_outside_quotes(haystack, needle, start_i=0, quotes='"'):
     quoted = None
     h_len = len(haystack)
     n_len = len(needle)
-    for i in xrange(start_i, h_len-n_len+1):
+    for i in range(start_i, h_len-n_len+1):
         if not quoted:
             if haystack[i:i+n_len] == needle:
                 return i
@@ -104,6 +103,7 @@ class Server(object):
 
         self.io = IO(socket, tls_wrapper)
 
+        self.bannered = False
         self.have_mailfrom = None
         self.have_rcptto = None
         self.ehlo_as = None
@@ -155,7 +155,7 @@ class Server(object):
                 data = None
                 err = e
 
-        reply = Reply('250', '2.6.0 Message Accepted for Delivery')
+        reply = Reply('250', '2.6.0 Message accepted for delivery')
         self._call_custom_handler('HAVE_DATA', reply, data, err)
 
         self.io.send_reply(reply)
@@ -170,6 +170,10 @@ class Server(object):
         self._call_custom_handler('TLSHANDSHAKE')
         return True
 
+    def _check_close_code(self, reply):
+        if reply.code in ('221', '421'):
+            raise StopIteration()
+
     def _handle_command(self, which, arg):
         method = '_command_'+which
         if hasattr(self, method):
@@ -202,10 +206,11 @@ class Server(object):
                     else:
                         unknown_command.send(self.io)
                 except StopIteration:
+                    self._call_custom_handler('CLOSE')
                     break
                 except ConnectionLost:
                     raise
-                except Exception as e:
+                except Exception:
                     unhandled_error.send(self.io)
                     raise
                 finally:
@@ -241,12 +246,16 @@ class Server(object):
         self._call_custom_handler('BANNER_', reply)
 
         reply.send(self.io)
+        self._check_close_code(reply)
 
-        if reply.code != '220':
-            self._call_custom_handler('CLOSE')
-            raise StopIteration()
+        if reply.code == '220':
+            self.bannered = True
 
     def _command_EHLO(self, ehlo_as):
+        if not self.bannered:
+            bad_sequence.send(self.io)
+            return
+
         reply = Reply('250', 'Hello {0}'.format(ehlo_as))
         reply.enhanced_status_code = False
         self._call_custom_handler('EHLO', reply, ehlo_as)
@@ -260,11 +269,18 @@ class Server(object):
             self.ehlo_as = ehlo_as
 
         reply.send(self.io)
+        self._check_close_code(reply)
 
     def _command_HELO(self, ehlo_as):
+        if not self.bannered:
+            bad_sequence.send(self.io)
+            return
+
         reply = Reply('250', 'Hello {0}'.format(ehlo_as))
         reply.enhanced_status_code = False
         self._call_custom_handler('HELO', reply, ehlo_as)
+        reply.send(self.io)
+        self._check_close_code(reply)
 
         if reply.code == '250':
             self.have_mailfrom = None
@@ -272,25 +288,21 @@ class Server(object):
             self.ehlo_as = ehlo_as
             self.extensions.reset()
 
-        reply.send(self.io)
-
     def _command_STARTTLS(self, arg):
         if 'STARTTLS' not in self.extensions:
             unknown_command.send(self.io)
             return
-
         if arg:
             bad_arguments.send(self.io)
             return
-
         if not self.ehlo_as:
             bad_sequence.send(self.io)
             return
 
         reply = Reply('220', '2.7.0 Go ahead')
         self._call_custom_handler('STARTTLS', reply, self.extensions)
-
         reply.send(self.io, flush=True)
+        self._check_close_code(reply)
 
         if reply.code == '220':
             if not self._encrypt_session():
@@ -320,6 +332,7 @@ class Server(object):
         reply = Reply('235', '2.7.0 Authentication successful')
         self._call_custom_handler('AUTH', reply, result)
         reply.send(self.io)
+        self._check_close_code(reply)
 
         if reply.code == '235':
             self.authed = True
@@ -365,8 +378,8 @@ class Server(object):
 
         reply = Reply('250', '2.1.0 Sender <{0}> Ok'.format(address))
         self._call_custom_handler('MAIL', reply, address, params)
-
         reply.send(self.io)
+        self._check_close_code(reply)
 
         self.have_mailfrom = self.have_mailfrom or (reply.code == '250')
 
@@ -391,8 +404,8 @@ class Server(object):
 
         reply = Reply('250', '2.1.5 Recipient <{0}> Ok'.format(address))
         self._call_custom_handler('RCPT', reply, address, params)
-
         reply.send(self.io)
+        self._check_close_code(reply)
 
         self.have_rcptto = self.have_rcptto or (reply.code == '250')
 
@@ -407,9 +420,8 @@ class Server(object):
 
         reply = Reply('354', 'Start mail input; end with <CRLF>.<CRLF>')
         self._call_custom_handler('DATA', reply)
-
-        reply.send(self.io)
-        self.io.flush_send()
+        reply.send(self.io, flush=True)
+        self._check_close_code(reply)
 
         if reply.code == '354':
             self._get_message_data()
@@ -421,18 +433,18 @@ class Server(object):
 
         reply = Reply('250', 'Ok')
         self._call_custom_handler('RSET', reply)
+        reply.send(self.io)
+        self._check_close_code(reply)
 
         if reply.code == '250':
             self.have_mailfrom = None
             self.have_rcptto = None
 
-        reply.send(self.io)
-
     def _command_NOOP(self, arg):
         reply = Reply('250', 'Ok')
         self._call_custom_handler('NOOP', reply)
-
         reply.send(self.io)
+        self._check_close_code(reply)
 
     def _command_QUIT(self, arg):
         if arg:
@@ -441,19 +453,15 @@ class Server(object):
 
         reply = Reply('221', 'Bye')
         self._call_custom_handler('QUIT', reply)
-
         reply.send(self.io)
-
-        if reply.code == '221':
-            self._call_custom_handler('CLOSE')
-            raise StopIteration()
+        self._check_close_code(reply)
 
     def _command_custom(self, command, arg):
         reply = Reply()
         reply.copy(unknown_command)
         self._call_custom_handler(command, reply, arg, self)
-
         reply.send(self.io)
+        self._check_close_code(reply)
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
