@@ -1,4 +1,5 @@
 
+import six
 import unittest2 as unittest
 
 
@@ -9,7 +10,7 @@ class TestSlimtaCore(unittest.TestCase):
 
     def test_import_slimta_core_version(self):
         from slimta.core import __version__
-        self.assertIsInstance(__version__, basestring)
+        self.assertIsInstance(__version__, six.string_types)
 
     def test_import_slimta_core_slimtaerror(self):
         from slimta.core import SlimtaError
