@@ -1,8 +1,9 @@
+from __future__ import unicode_literals
 
 import time
 
 import unittest2 as unittest
-from mox import MoxTestBase
+from mox3.mox import MoxTestBase
 
 from slimta.edge import Edge, EdgeServer
 
