@@ -1,13 +1,11 @@
+from __future__ import unicode_literals
 
 import unittest2 as unittest
-from mox import MoxTestBase, IsA, IgnoreArg
+from mox3.mox import MoxTestBase, IsA, IgnoreArg
 import gevent
 from gevent.socket import create_connection
-from dns.resolver import NXDOMAIN
-from dns.exception import DNSException
 
 from slimta.edge.smtp import SmtpEdge, SmtpSession
-from slimta.util import dns_resolver
 from slimta.envelope import Envelope
 from slimta.queue import QueueError
 from slimta.smtp.reply import Reply
@@ -101,7 +99,7 @@ class TestEdgeSmtp(unittest.TestCase, MoxTestBase):
         h = SmtpSession(('127.0.0.1', 0), None, handoff)
         h.envelope = env
         reply = Reply('250')
-        h.HAVE_DATA(reply, '', None)
+        h.HAVE_DATA(reply, b'', None)
         self.assertEqual('250', reply.code)
         self.assertEqual('2.6.0 Message accepted for delivery', reply.message)
 
@@ -113,7 +111,7 @@ class TestEdgeSmtp(unittest.TestCase, MoxTestBase):
         h = SmtpSession(('127.0.0.1', 0), None, handoff)
         h.envelope = env
         reply = Reply('250')
-        h.HAVE_DATA(reply, '', None)
+        h.HAVE_DATA(reply, b'', None)
         self.assertEqual('550', reply.code)
         self.assertEqual('5.6.0 Error queuing message', reply.message)
 
