@@ -1,20 +1,14 @@
 
-from StringIO import StringIO
-from base64 import b64encode
+from io import BytesIO
 
-import unittest2 as unittest
-from mox import MoxTestBase, IsA, IgnoreArg
-import gevent
-from dns.exception import DNSException
+from mox3.mox import MoxTestBase, IsA
 
 from slimta.edge.wsgi import WsgiEdge, WsgiValidators
-from slimta.util import dns_resolver
 from slimta.envelope import Envelope
 from slimta.queue import QueueError
-from slimta.smtp.reply import Reply
 
 
-class TestEdgeWsgi(unittest.TestCase, MoxTestBase):
+class TestEdgeWsgi(MoxTestBase):
 
     def setUp(self):
         super(TestEdgeWsgi, self).setUp()
@@ -22,23 +16,10 @@ class TestEdgeWsgi(unittest.TestCase, MoxTestBase):
         self.queue = self.mox.CreateMockAnything()
         self.environ = {'REQUEST_METHOD': 'POST',
                         'HTTP_X_EHLO': 'test',
-                        'HTTP_X_ENVELOPE_SENDER': b64encode('sender@example.com'),
-                        'HTTP_X_ENVELOPE_RECIPIENT': '{0}, {1}'.format(b64encode('rcpt1@example.com'), b64encode('rcpt2@example.com')),
+                        'HTTP_X_ENVELOPE_SENDER': 'c2VuZGVyQGV4YW1wbGUuY29t',
+                        'HTTP_X_ENVELOPE_RECIPIENT': 'cmNwdDFAZXhhbXBsZS5jb20=, cmNwdDJAZXhhbXBsZS5jb20=',
                         'HTTP_X_CUSTOM_HEADER': 'custom test',
-                        'wsgi.input': StringIO('')}
-
-    def test_ptr_lookup(self):
-        environ = self.environ.copy()
-        environ['REMOTE_ADDR'] = '1.2.3.4'
-        self.mox.StubOutWithMock(dns_resolver, 'query')
-        dns_resolver.query(IgnoreArg(), 'PTR').AndRaise(DNSException)
-        dns_resolver.query(IgnoreArg(), 'PTR').AndReturn(['example.com'])
-        self.mox.ReplayAll()
-        w = WsgiEdge(None)
-        w._ptr_lookup(environ)
-        self.assertNotIn('slimta.reverse_address', environ)
-        w._ptr_lookup(environ)
-        self.assertEqual('example.com', environ['slimta.reverse_address'])
+                        'wsgi.input': BytesIO(b'')}
 
     def test_invalid_path(self):
         environ = self.environ.copy()
@@ -85,7 +66,7 @@ class TestEdgeWsgi(unittest.TestCase, MoxTestBase):
                 return False
             return True
         self.queue.enqueue(IsA(Envelope)).AndReturn([(Envelope(), 'testid')])
-        self.start_response.__call__('200 OK', IsA(list))
+        self.start_response.__call__('204 No Content', IsA(list))
         self.mox.ReplayAll()
         w = WsgiEdge(self.queue)
         self.assertEqual([], w(self.environ, self.start_response))
