@@ -1,36 +1,52 @@
+from __future__ import unicode_literals
 
 import unittest2 as unittest
 
-from mox import MoxTestBase, IsA
-import gevent
-from dns.resolver import NXDOMAIN
+from mox3.mox import MoxTestBase
+from pycares.errno import ARES_ENOTFOUND
 
-from slimta.util import dns_resolver
+from slimta.util.dns import DNSResolver, DNSError
 from slimta.util.dnsbl import DnsBlocklist, DnsBlocklistGroup, check_dnsbl
 from slimta.smtp.reply import Reply
 
 
+class FakeRdata(object):
+
+    def __init__(self, text):
+        self.text = text
+
+
+class FakeAsyncResult(object):
+
+    def __init__(self, answers=None):
+        self.answers = answers and [FakeRdata(answer) for answer in answers]
+
+    def get(self):
+        return self.answers
+
+
+
 class TestDnsbl(unittest.TestCase, MoxTestBase):
 
     def setUp(self):
         super(TestDnsbl, self).setUp()
-        self.mox.StubOutWithMock(dns_resolver, 'query')
+        self.mox.StubOutWithMock(DNSResolver, 'query')
         self.dnsbl = DnsBlocklist('test.example.com')
 
     def test_dnsblocklist_build_query(self):
         self.assertEqual('4.3.2.1.test.example.com', self.dnsbl._build_query('1.2.3.4'))
 
     def test_dnsblocklist_get(self):
-        dns_resolver.query('4.3.2.1.test.example.com', 'A')
-        dns_resolver.query('8.7.6.5.test.example.com', 'A').AndRaise(NXDOMAIN)
+        DNSResolver.query('4.3.2.1.test.example.com', 'A').AndReturn(FakeAsyncResult())
+        DNSResolver.query('8.7.6.5.test.example.com', 'A').AndRaise(DNSError(ARES_ENOTFOUND))
         self.mox.ReplayAll()
         self.assertTrue(self.dnsbl.get('1.2.3.4'))
         self.assertNotIn('5.6.7.8', self.dnsbl)
 
     def test_dnsblocklist_get_reason(self):
-        dns_resolver.query('4.3.2.1.test.example.com', 'TXT')
-        dns_resolver.query('4.3.2.1.test.example.com', 'TXT').AndReturn(['good reason'])
-        dns_resolver.query('8.7.6.5.test.example.com', 'TXT').AndRaise(NXDOMAIN)
+        DNSResolver.query('4.3.2.1.test.example.com', 'TXT').AndReturn(FakeAsyncResult())
+        DNSResolver.query('4.3.2.1.test.example.com', 'TXT').AndReturn(FakeAsyncResult(['good reason']))
+        DNSResolver.query('8.7.6.5.test.example.com', 'TXT').AndRaise(DNSError(ARES_ENOTFOUND))
         self.mox.ReplayAll()
         self.assertEqual(None, self.dnsbl.get_reason('1.2.3.4'))
         self.assertEqual('good reason', self.dnsbl.get_reason('1.2.3.4'))
@@ -41,12 +57,12 @@ class TestDnsbl(unittest.TestCase, MoxTestBase):
         group.add_dnsbl('test1.example.com')
         group.add_dnsbl('test2.example.com')
         group.add_dnsbl('test3.example.com')
-        dns_resolver.query('4.3.2.1.test1.example.com', 'A').InAnyOrder('one')
-        dns_resolver.query('4.3.2.1.test2.example.com', 'A').InAnyOrder('one').AndRaise(NXDOMAIN)
-        dns_resolver.query('4.3.2.1.test3.example.com', 'A').InAnyOrder('one')
-        dns_resolver.query('8.7.6.5.test1.example.com', 'A').InAnyOrder('two').AndRaise(NXDOMAIN)
-        dns_resolver.query('8.7.6.5.test2.example.com', 'A').InAnyOrder('two').AndRaise(NXDOMAIN)
-        dns_resolver.query('8.7.6.5.test3.example.com', 'A').InAnyOrder('two').AndRaise(NXDOMAIN)
+        DNSResolver.query('4.3.2.1.test1.example.com', 'A').InAnyOrder('one').AndReturn(FakeAsyncResult())
+        DNSResolver.query('4.3.2.1.test2.example.com', 'A').InAnyOrder('one').AndRaise(DNSError(ARES_ENOTFOUND))
+        DNSResolver.query('4.3.2.1.test3.example.com', 'A').InAnyOrder('one').AndReturn(FakeAsyncResult())
+        DNSResolver.query('8.7.6.5.test1.example.com', 'A').InAnyOrder('two').AndRaise(DNSError(ARES_ENOTFOUND))
+        DNSResolver.query('8.7.6.5.test2.example.com', 'A').InAnyOrder('two').AndRaise(DNSError(ARES_ENOTFOUND))
+        DNSResolver.query('8.7.6.5.test3.example.com', 'A').InAnyOrder('two').AndRaise(DNSError(ARES_ENOTFOUND))
         self.mox.ReplayAll()
         self.assertEqual(set(['test1.example.com', 'test3.example.com']), group.get('1.2.3.4'))
         self.assertNotIn('5.6.7.8', group)
@@ -56,8 +72,8 @@ class TestDnsbl(unittest.TestCase, MoxTestBase):
         group.add_dnsbl('test1.example.com')
         group.add_dnsbl('test2.example.com')
         group.add_dnsbl('test3.example.com')
-        dns_resolver.query('4.3.2.1.test1.example.com', 'TXT').InAnyOrder().AndReturn(['reason one'])
-        dns_resolver.query('4.3.2.1.test3.example.com', 'TXT').InAnyOrder()
+        DNSResolver.query('4.3.2.1.test1.example.com', 'TXT').InAnyOrder().AndReturn(FakeAsyncResult(['reason one']))
+        DNSResolver.query('4.3.2.1.test3.example.com', 'TXT').InAnyOrder().AndReturn(FakeAsyncResult())
         self.mox.ReplayAll()
         self.assertEqual({'test1.example.com': 'reason one', 'test3.example.com': None},
                          group.get_reasons(set(['test1.example.com', 'test3.example.com']), '1.2.3.4'))
@@ -72,8 +88,8 @@ class TestDnsbl(unittest.TestCase, MoxTestBase):
             def validate_mail(self, reply, sender):
                 assert False
 
-        dns_resolver.query('4.3.2.1.test.example.com', 'A').AndRaise(NXDOMAIN)
-        dns_resolver.query('4.3.2.1.test.example.com', 'A')
+        DNSResolver.query('4.3.2.1.test.example.com', 'A').AndRaise(DNSError(ARES_ENOTFOUND))
+        DNSResolver.query('4.3.2.1.test.example.com', 'A').AndReturn(FakeAsyncResult())
         self.mox.ReplayAll()
         validators = TestValidators()
         reply = Reply('250', '2.0.0 Ok')
@@ -85,5 +101,4 @@ class TestDnsbl(unittest.TestCase, MoxTestBase):
         self.assertEqual('5.7.1 Access denied', reply.message)
 
 
-
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
